@@ -23,13 +23,12 @@ class faker():
         else:
             return date
 
-# if __name__ == '__main__':
-#     host = 'xxxxxxxx'
-#     port = 12345
-#     user = 'root'
-#     password = ''
-#     database = 'AnyRobot'
-#     key = 'getDashboardId'
-#     restult = ['a3d4233a-554c-11eb-a7e2-96c65b9ffa1c',]
-#     date = faker(host,port,user,password,database).route(key)
-#     print(date)
\ No newline at end of file
+if __name__ == '__main__':
+    host = ''
+    port = ''
+    user = ''
+    password = ''
+    database = ''
+    key1 = ''
+    date1 = faker(host,port,user,password,database).route(key1)
+    print(date1)
\ No newline at end of file
